function A = draw_chess(m,n,r,pauseTime)

% This function draws the optimal tour for given m and n (size of the grid) 
% where the radius r is 0,1 or 2 (r = 2 stands for r = 2^0.5). The tour is plotted on a chessboard.
% These tours can be visualized for any m and n if r = 0, any m and n except
% m = 1 && n < 5 / m = 2 && n < 3 for r = 1 and any m and n except m = 3 &&
% n < 4 / m = 1 && n < 5 / m = 2 for r = 2.

% The idea of the program is to numerate the fields of A in the order they
% will be run through. (This is done by function numbering_matrix_...)
% Here a matrix B with size(A)+1 is created. The index of the current number of 
% A will be searched (started with 1, then 2 and so on) and at this index B
% will be set from 0 to 1 to change the colour (using pcolor, drawnow)


    colormap hot;
    help = false;
    if r == 0 || r == 1
        if n < m
           c = n;
           n = m;
           m = c;
           help = true;
        end
    end
    
    if r == 0
        A = numbering_matrix_zero(m,n);
    elseif r == 1
        if ( m == 1 && n <= 4 ) || ( m == 2 && n <= 2)
            errordlg('There do not exist feasible tours for this dimensions');
        elseif (m == 1) || (m == 2) || (m == 4)
            A = numbering_matrix_one_specialcases(m,n);
        elseif mod(m,2)==1 && mod(n,2)==1
            A = numbering_matrix_one_oddodd(m,n);
        else
            A = numbering_matrix_one(m,n);
        end
    elseif r == 2
        if (m == 1 && n < 5) || (m == 2) || (m == 3 && n < 4)
            errordlg('There does not exist a feasible tour for this dimension!');
        else
            A = numbering_matrix_sr2(m,n);
        end
    else
        errordlg('r has to be 0, 1 or 2!')
    end
    
    if help
        A = rot90(A);
    end
    
    B = zeros(size(A)+1);
    A = flipud(A);

    [row,col] = find(A==1);
    B(row,col)=0.95;
    pcolor(B)
    drawnow
    axis equal;
    hold on

    for i = 2:(n*m)-1,
        pause(pauseTime)
        [row,col]=find(A==i);
        B(row,col) = 2;
        pcolor(B)
        drawnow
    end
    pause(pauseTime)
    [row,col] = find(A==m*n);
    B(row,col)=1.2;
    pcolor(B)
    drawnow
    
    A = flipud(A);
    disp(A);
    